Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/gentrie/__init__.py | 6 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | 29 | 0 | 0 | 0 | 0 | 100%
src/gentrie/nodes.py | 33 | 1 | 2 | 10 | 1 | 95%
src/gentrie/protocols.py | 8 | 0 | 4 | 0 | 0 | 100%
src/gentrie/trie/__init__.py | 8 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/access.py | 37 | 0 | 0 | 20 | 0 | 100%
src/gentrie/trie/base.py | 39 | 0 | 2 | 4 | 1 | 98%
src/gentrie/trie/collection.py | 14 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/mutation.py | 9 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/removal.py | 36 | 0 | 0 | 12 | 0 | 100%
src/gentrie/trie/storage.py | 36 | 0 | 0 | 12 | 0 | 100%
src/gentrie/trie/traversal.py | 41 | 0 | 0 | 26 | 0 | 100%
src/gentrie/trie/trie_mixins.py | 14 | 0 | 12 | 0 | 0 | 100%
src/gentrie/types.py | 27 | 0 | 3 | 2 | 0 | 100%
src/gentrie/validation.py | 19 | 0 | 0 | 8 | 0 | 100%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/test_gentri.py | 454 | 1 | 2 | 8 | 1 | 99%
Total | 810 | 2 | 25 | 102 | 3 | 99%

No items found using the specified filter.